import { Component, Input, OnInit } from '@angular/core';

interface Partition {
  diskNumber: number;
  partitionNumber: number;
  associatedImage?: string;
  associatedOgLive?: string;
}

@Component({
  selector: 'app-restore-image',
  templateUrl: './restore-image.component.html',
  styleUrls: ['./restore-image.component.css']
})
export class RestoreImageComponent implements OnInit {
  @Input() data: any;

  disks: { diskNumber: number; partitions: Partition[] }[] = [];
  availableImages: string[] = [];
  availableOgLives: string[] = [];

  ngOnInit(): void {
    this.initializeDisks();
    this.availableImages = ['Windows10.iso', 'Ubuntu.iso', 'macOS.iso'];
    this.availableOgLives = ['LiveCD1', 'LiveCD2', 'LiveCD3'];
  }

  initializeDisks() {
    const partitionsFromData = this.data.partitions;
    const disksMap = new Map<number, Partition[]>();

    partitionsFromData.forEach((partition: any) => {
      if (!disksMap.has(partition.diskNumber)) {
        disksMap.set(partition.diskNumber, []);
      }

      disksMap.get(partition.diskNumber)!.push({
        diskNumber: partition.diskNumber,
        partitionNumber: partition.partitionNumber
      });
    });

    disksMap.forEach((partitions, diskNumber) => {
      this.disks.push({ diskNumber, partitions });
    });
  }

  onImageSelected(partition: Partition, event: Event) {
    const selectElement = event.target as HTMLSelectElement;
    partition.associatedImage = selectElement.value;
  }

  onOgLiveSelected(partition: Partition, event: Event) {
    const selectElement = event.target as HTMLSelectElement;
    partition.associatedOgLive = selectElement.value;
  }

  saveAssociations() {
    this.disks.forEach(disk => {
      disk.partitions.forEach(partition => {
        if (partition.associatedImage || partition.associatedOgLive) {
          console.log(`Guardando para disco ${partition.diskNumber}, partición ${partition.partitionNumber}, Imagen: ${partition.associatedImage}, OgLive: ${partition.associatedOgLive}`);

        }
      });
    });
  }
}
